@@ -16,9 +16,9 @@ class Rule:
     sources: SourceClasses = []
     stores: StoreClasses = []
 
-    def __init__(self, monitor: MonitorInstance):
+    def __init__(self, monitor: MonitorInstance, *sources: SourceInstance):
         self.monitor = monitor
 
-    def evaluate(self, *sources: SourceInstance) -> Evaluation:
+    def evaluate(self) -> Evaluation:
         """The evalutation function is called by the monitor, which stores any returned metrics."""
         return None
