@@ -28,6 +28,7 @@ class MetricSource(Source, Memory):
         checked: NullableBool = None,
         context: str = "",
         monitor_id: str = "",
+        updated_at: Any = None,
     ) -> MetricList:
         """Get a metric/metrics from the Source"""
         metric_filter: JDict = {}
@@ -43,6 +44,8 @@ class MetricSource(Source, Memory):
             metric_filter["checked"] = checked
         if monitor_id:
             metric_filter["monitor_id"] = monitor_id
+        if monitor_id:
+            metric_filter["updated_at"] = updated_at
         return self._execute_query(metric_filter)
 
     def _execute_query(self, metric_filter: JDict) -> MetricList:
